Package: RProtoBuf
Version: 0.4.28
Date: 2026-08-20
Authors@R: c(person("Romain", "Francois", role = "aut",
                    comment = c(ORCID = "0000-0002-2444-4226")),
             person("Dirk", "Eddelbuettel", role = c("aut", "cre"), email = "edd@debian.org",
                    comment = c(ORCID = "0000-0001-6419-907X")),
             person("Murray", "Stokely", role = "aut",
                    comment = c(ORCID = "0009-0008-3390-1338")),
             person("Jeroen", "Ooms", role = "aut",
                    comment = c(ORCID = "0000-0002-4035-0289")))
Title: R Interface to the 'Protocol Buffers' 'API' (Version 2 or 3)
Description: Protocol Buffers are a way of encoding structured data in an
 efficient yet extensible format. Google uses Protocol Buffers for almost all
 of its internal 'RPC' protocols and file formats.  Additional documentation
 is available in two included vignettes one of which corresponds to our 'JSS'
 paper (2016, <doi:10.18637/jss.v071.i02>. A sufficiently recent version of
 'Protocol Buffers' library is required; currently version 3.3.0 from 2017
 is the tested minimum.
Imports: methods, utils, stats, tools, Rcpp
LinkingTo: Rcpp
Suggests: tinytest
SystemRequirements: ProtoBuf libraries and compiler version 3.3.0 or
        later; On Debian/Ubuntu these can be installed as
        libprotoc-dev, libprotobuf-dev and protobuf-compiler, while on
        Fedora/CentOS protobuf-devel and protobuf-compiler are needed.
        A modern compiler is required as well.
BugReports: https://github.com/eddelbuettel/rprotobuf/issues
URL: https://github.com/eddelbuettel/rprotobuf,
        https://dirk.eddelbuettel.com/code/rprotobuf.html
License: GPL (>= 2)
VignetteBuilder: Rcpp
NeedsCompilation: yes
Packaged: 2026-08-21 13:39:09 UTC; edd
Author: Romain Francois [aut] (ORCID: <https://orcid.org/0000-0002-2444-4226>),
  Dirk Eddelbuettel [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-6419-907X>),
  Murray Stokely [aut] (ORCID: <https://orcid.org/0009-0008-3390-1338>),
  Jeroen Ooms [aut] (ORCID: <https://orcid.org/0000-0002-4035-0289>)
Maintainer: Dirk Eddelbuettel <edd@debian.org>
Repository: CRAN
Date/Publication: 2026-08-21 22:01:25 UTC
Built: R 4.5.2; x86_64-apple-darwin20; 2026-08-21 23:16:07 UTC; unix
Archs: RProtoBuf.so.dSYM
