# Copyright 2014 Google Inc.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

library(RProtoBuf)

#test.descriptor <- function() {
expect_true(inherits(tutorial.Person$email, "FieldDescriptor"))
expect_true(inherits(tutorial.Person[["email"]], "FieldDescriptor"))
expect_true(inherits(tutorial.Person[[1]], "FieldDescriptor"))
## Currently, the $ extractor for fields returns NULL for invalid reference
## stop() probably better.
expect_equal(tutorial.Person$nonexistantfoobarbaz, NULL)
## But we raise an error with invalid indices with '[['.
expect_error(tutorial.Person[[909]])
expect_error(tutorial.Person[["nonexistantfoobarbaz"]])
#}
