\name{Next-methods}
\docType{methods}
\alias{Next}
\alias{Next-methods}
\title{Obtains a chunk of data from the stream}
\description{
Obtains a chunk of data from the stream
}
\seealso{
	\linkS4class{ZeroCopyInputStream} implements Next.
}
\keyword{methods}

