\name{is_extension-methods}
\alias{is_extension}
\alias{is_extension-methods}
\title{Indicates if a field descriptor is an extension}
\description{
  Indicates if a field descriptor is an extension
}
\seealso{
  The method is implemented for the \linkS4class{FieldDescriptor} class
}
\keyword{methods}
\examples{
Person <- P( "tutorial.Person" )
is_extension(Person$id)
}