\name{field-methods}
\alias{field}
\alias{field-methods}
\title{Extract a field descriptor}
\description{
	Extract a \linkS4class{FieldDescriptor} from a 
	\linkS4class{Descriptor}
}
\seealso{
The method is implemented for the \linkS4class{Descriptor} class
}
\keyword{methods}

