\name{BackUp-methods}
\docType{methods}
\alias{BackUp}
\alias{BackUp-methods}
\title{Backs up a number of bytes from a stream}
\description{
Backs up a number of bytes from a stream
}
\seealso{
	\linkS4class{ZeroCopyInputStream} implements BackUp.
}
\keyword{methods}

