\name{nested_type_count-methods}
\alias{nested_type_count}
\alias{nested_type_count-methods}
\title{The number of fields}
\description{
The number of fields 
}
\seealso{
The method is implemented for the \linkS4class{Descriptor} class
}
\keyword{methods}

